==> iReport-0.4.1-src.zip: iReport-0.4.1-src/src/it/businesslogic/ireport/OperationType.java <==
/*
 *  iReport  --  Visual designer for generating JasperReports Documents
 *  Copyright (C) 2002  Giulio Toffoli gt@businesslogic.it
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 *  Giulio Toffoli
 *  Via T.Aspetti, 233
 *  35100 Padova ITALY
 *  gt@businesslogic.it
 */
package it.businesslogic.ireport;

public class OperationType
{
	public static final int ALIGN_LEFT				=1;
	public static final int ALIGN_RIGHT				=2;
	public static final int ALIGN_TOP				=3;
	public static final int ALIGN_BOTTOM				=4;
	public static final int ALIGN_CENTER_VERTICALLY                 =5;
	public static final int ALIGN_CENTER_HORIZONTALLY               =6;
	public static final int ALIGN_CENTER				=7;
	public static final int ALIGN_VERTICAL_AXIS                     =8;
	public static final int ALIGN_HORIZONTAL_AXIS                   =9;
	
	public static final int SAME_SIZE				=10;
	public static final int SAME_WIDTH				=11;
	public static final int SAME_HEIGHT				=12;
	
	public static final int SPACE_HORIZONTALLY                      =12;
	public static final int SPACE_VERTICALLY                        =13;
	
	public static final int ALIGN_TOP_TO_BAND                       =14;
        public static final int ALIGN_BOTTOM_TO_BAND                    =15;
	public static final int BRING_TO_FRON                           =16;
	public static final int SEND__TO_BACK                           =17;
        
        public static final int SAME_WIDTH_MAX				=18;
	public static final int SAME_HEIGHT_MAX				=19;
        public static final int SAME_WIDTH_MIN				=20;
	public static final int SAME_HEIGHT_MIN				=21;
        
        public static final int CENTER_IN_BAND_H                        =22;
        public static final int CENTER_IN_BAND_V                        =23;
        public static final int CENTER_IN_BAND                          =24;
        public static final int CENTER_IN_BACKGROUND                    =25;
        public static final int JOIN_LEFT                               =26;
        public static final int JOIN_RIGHT                              =27;
        
        public static final int EQUALS_SPACE_H                          =28;
        public static final int INCREASE_SPACE_H                        =29;
        public static final int DECREASE_SPACE_H                        =30;
        public static final int REMOVE_SPACE_H                          =31;       
        
        public static final int EQUALS_SPACE_V                          =32;
        public static final int INCREASE_SPACE_V                        =33;
        public static final int DECREASE_SPACE_V                        =34;
        public static final int REMOVE_SPACE_V                          =35;
        
        public static final int ALIGN_TO_LEFT_MARGIN                    =36;
        public static final int ALIGN_TO_RIGHT_MARGIN                   =37;
        public static final int MOVE_TO_LEFT_MARGIN                     =38;
        
        public static final int ORGANIZE_AS_A_TABLE                     =39;

}

==> iReport-0.5.0-src.zip: iReport-0.5.0-src/src/it/businesslogic/ireport/OperationType.java <==
/*
 *  iReport  --  Visual designer for generating JasperReports Documents
 *  Copyright (C) 2002  Giulio Toffoli gt@businesslogic.it
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 *  Giulio Toffoli
 *  Via T.Aspetti, 233
 *  35100 Padova ITALY
 *  gt@businesslogic.it
 */
package it.businesslogic.ireport;

public class OperationType
{
	public static final int ALIGN_LEFT				=1;
	public static final int ALIGN_RIGHT				=2;
	public static final int ALIGN_TOP				=3;
	public static final int ALIGN_BOTTOM				=4;
	public static final int ALIGN_CENTER_VERTICALLY                 =5;
	public static final int ALIGN_CENTER_HORIZONTALLY               =6;
	public static final int ALIGN_CENTER				=7;
	public static final int ALIGN_VERTICAL_AXIS                     =8;
	public static final int ALIGN_HORIZONTAL_AXIS                   =9;
	
	public static final int SAME_SIZE				=10;
	public static final int SAME_WIDTH				=11;
	public static final int SAME_HEIGHT				=12;
	
	public static final int SPACE_HORIZONTALLY                      =12;
	public static final int SPACE_VERTICALLY                        =13;
	
	public static final int ALIGN_TOP_TO_BAND                       =14;
        public static final int ALIGN_BOTTOM_TO_BAND                    =15;
	public static final int BRING_TO_FRON                           =16;
	public static final int SEND__TO_BACK                           =17;
        
        public static final int SAME_WIDTH_MAX				=18;
	public static final int SAME_HEIGHT_MAX				=19;
        public static final int SAME_WIDTH_MIN				=20;
	public static final int SAME_HEIGHT_MIN				=21;
        
        public static final int CENTER_IN_BAND_H                        =22;
        public static final int CENTER_IN_BAND_V                        =23;
        public static final int CENTER_IN_BAND                          =24;
        public static final int CENTER_IN_BACKGROUND                    =25;
        public static final int JOIN_LEFT                               =26;
        public static final int JOIN_RIGHT                              =27;
        
        public static final int EQUALS_SPACE_H                          =28;
        public static final int INCREASE_SPACE_H                        =29;
        public static final int DECREASE_SPACE_H                        =30;
        public static final int REMOVE_SPACE_H                          =31;       
        
        public static final int EQUALS_SPACE_V                          =32;
        public static final int INCREASE_SPACE_V                        =33;
        public static final int DECREASE_SPACE_V                        =34;
        public static final int REMOVE_SPACE_V                          =35;
        
        public static final int ALIGN_TO_LEFT_MARGIN                    =36;
        public static final int ALIGN_TO_RIGHT_MARGIN                   =37;
        public static final int MOVE_TO_LEFT_MARGIN                     =38;
        public static final int MOVE_TO_RIGHT_MARGIN                    =39;
        
        public static final int ORGANIZE_AS_A_TABLE                     =40;
        public static final int ELEMENT_MAXIMIZE                        =41;
        public static final int ELEMENT_MAXIMIZE_H                      =42;
        public static final int ELEMENT_MAXIMIZE_V                      =43;
}
